@@ -1,5 +1,5 @@
 # function plots posterior density of mapped states from stochastic mapping
-# written by Liam J. Revell 2012, 2013, 2014, 2015, 2016
+# written by Liam J. Revell 2012, 2013, 2014, 2015, 2016, 2021
 
 densityMap<-function(trees,res=100,fsize=NULL,ftype=NULL,lwd=3,check=FALSE,legend=NULL,
 	outline=FALSE,type="phylogram",direction="rightwards",plot=TRUE,...){
@@ -72,7 +72,9 @@ densityMap<-function(trees,res=100,fsize=NULL,ftype=NULL,lwd=3,check=FALSE,legen
 	tree$mapped.edge<-makeMappedEdge(tree$edge,tree$maps)
 	tree$mapped.edge<-tree$mapped.edge[,order(as.numeric(colnames(tree$mapped.edge)))]
 	class(tree)<-c("simmap",setdiff(class(tree),"simmap"))
-	x<-list(tree=tree,cols=cols,states=ss); class(x)<-"densityMap"
+	attr(tree,"map.order")<-"right-to-left"
+	x<-list(tree=tree,cols=cols,states=ss)
+	class(x)<-"densityMap"
 	if(plot) plot.densityMap(x,fsize=fsize,ftype=ftype,lwd=lwd,legend=legend,outline=outline,
 		type=type,mar=mar,direction=direction,offset=offset,hold=hold)
 	invisible(x)
@@ -80,7 +82,7 @@ densityMap<-function(trees,res=100,fsize=NULL,ftype=NULL,lwd=3,check=FALSE,legen
 
 ## S3 plot method for objects of class "densityMap"
 ## also used internally by plot.contMap
-## written by Liam J. Revell 2012, 2013, 2014, 2015, 2016
+## written by Liam J. Revell 2012, 2013, 2014, 2015, 2016, 2020
 
 plot.densityMap<-function(x,...){
 	if(class(x)=="densityMap"){
@@ -131,14 +133,29 @@ plot.densityMap<-function(x,...){
 	}
 	if(hold) null<-dev.hold()
 	if(type=="phylogram"){
+		if(direction%in%c("upwards","downwards")&&legend){
+			par(mar=mar)
+			plot.new()
+		}
 		N<-length(tree$tip.label)
-		if(legend&&is.null(ylim)) ylim<-c(1-0.12*(N-1),N)
-		else if(is.null(ylim)) ylim<-NULL
+		if(legend&&is.null(ylim)){
+			if(direction%in%c("rightwards","leftwards")) ylim<-c(1-0.12*(N-1),N)
+			else {
+				pp<-par("pin")[2]
+				sw<-(fsize*(max(strwidth(x$tree$tip.label,units="inches")))+
+					1.37*fsize*strwidth("W",units="inches"))[1]
+				alp<-optimize(function(a,H,sw,pp) (a*1.2*max(H)+sw-pp)^2,H=H,sw=sw,pp=pp,
+					interval=c(0,1e6))$minimum
+				ylim<-if(direction=="downwards") c(min(H)-sw/alp-0.16*max(H),max(H)) else 
+					c(min(H)-0.16*max(H),max(H)+sw/alp)
+			}
+		} else if(is.null(ylim)) ylim<-NULL
 		if(outline){
 			par(col="transparent")
 			plotTree(tree,fsize=fsize[1],lwd=lwd[1]+2,
 				offset=offset+0.2*lwd[1]/3+0.2/3,ftype=ftype[1],xlim=xlim,
-				ylim=ylim,mar=mar,direction=direction,hold=FALSE)
+				ylim=ylim,mar=mar,direction=direction,hold=FALSE,
+				add=direction%in%c("upwards","downwards")&&legend)
 			par(col="black")
 		}
 		plotSimmap(tree,cols,pts=FALSE,lwd=lwd[1],fsize=fsize[1],mar=mar,ftype=ftype[1],add=outline,
@@ -150,23 +167,33 @@ plot.densityMap<-function(x,...){
 				dig
 			}
 			dig<-max(sapply(strsplit(leg.txt[c(1,3)],split=""),ff))
-			add.color.bar(legend,cols,title=leg.txt[2],lims<-as.numeric(leg.txt[c(1,3)]),
-				digits=dig,prompt=FALSE,x=if(direction=="leftwards") max(H)-legend else 0,
-				y=1-0.08*(N-1),lwd=lwd[2],
-				fsize=fsize[2],
-				direction=if(!is.null(xlim)) if(xlim[2]<xlim[1]) "leftwards" else "rightwards" else "rightwards")
+			if(direction%in%c("rightwards","leftwards"))
+				add.color.bar(legend,cols,title=leg.txt[2],lims<-as.numeric(leg.txt[c(1,3)]),
+					digits=dig,prompt=FALSE,x=if(direction=="leftwards") max(H)-legend else 0,
+					y=1-0.08*(N-1),lwd=lwd[2],
+					fsize=fsize[2],
+					direction=if(!is.null(xlim)) if(xlim[2]<xlim[1]) "leftwards" else 
+					"rightwards" else "rightwards")
+			else if(direction%in%c("upwards","downwards")){
+				sf<-abs(diff(par()$usr[1:2])/diff(par()$usr[3:4]))*
+					par()$pin[2]/par()$pin[1]
+				add.color.bar(legend*sf,cols,title=leg.txt[2],lims<-as.numeric(leg.txt[c(1,3)]),
+					digits=dig,prompt=FALSE,x=1,y=ylim[1]+0.04*max(nodeHeights(x$tree)),lwd=lwd[2],
+					fsize=fsize[2],direction="rightwards",subtitle=paste("length=",round(legend,
+					3),sep=""))
+			}
 		}
 	} else if(type=="fan"){
 		if(outline){
 			par(col="white")
 			invisible(capture.output(plotTree(tree,type="fan",lwd=lwd[1]+2,
 				mar=mar,fsize=fsize[1],
-				ftype=ftype[1],xlim=xlim,ylim=ylim,hold=FALSE)))
+				ftype=ftype[1],xlim=xlim,ylim=ylim,hold=FALSE,offset=offset)))
 			par(col="black")
 		}
 		invisible(capture.output(plotSimmap(tree,cols,lwd=lwd[1],
 			mar=mar,fsize=fsize[1],add=outline,ftype=ftype[1],
-			type="fan",xlim=xlim,ylim=ylim,hold=FALSE)))
+			type="fan",xlim=xlim,ylim=ylim,hold=FALSE,offset=offset)))
 		if(legend){
 			ff<-function(dd){
 				if(!("."%in%dd)) dig<-0
@@ -191,10 +218,29 @@ print.densityMap<-function(x,...){
 	cat(paste("(2) The mapped posterior density of a discrete binary character with states (",x$states[1],", ",x$states[2],").\n\n",sep="")) 
 }
 
-## set new color map for object of class 'densityMap' or 'contMap'
-## written by Liam J. Revell 2014
+## set new color map for object of class 'densityMap', 'contMap', or
+## 'phyloScattergram'
+## written by Liam J. Revell 2014, 2019
 
-setMap<-function(x,...){
+setMap<-function(x,...) UseMethod("setMap")
+
+setMap.default<-function(x,...){
+	warning(paste(
+		"setMap does not know how to handle objects of class ",
+		class(x),
+		"\nand can only be used on classes contMap, densityMap, & phyloScattergram."))
+}
+
+setMap.contMap<-function(x,...) SetMap(x,...)
+
+setMap.densityMap<-function(x,...) SetMap(x,...)
+
+setMap.phyloScattergram<-function(x,...){
+	x$contMaps<-lapply(x$contMaps,setMap,...)
+	x
+}
+
+SetMap<-function(x,...){
 	if(hasArg(invert)) invert<-list(...)$invert
 	else invert<-FALSE
 	n<-length(x$cols)
@@ -206,10 +252,10 @@ setMap<-function(x,...){
 ## drop tips from an object of class 'densityMap'
 ## written by Liam J. Revell 2014, 2015
 
-drop.tip.densityMap<-function(x,tip){
+drop.tip.densityMap<-function(x,tip,...){
 	if(inherits(x,"densityMap")){ 
 		class(x)<-"contMap"
-		x<-drop.tip.contMap(x,tip)
+		x<-drop.tip.contMap(x,tip,...)
 		class(x)<-"densityMap"
 		return(x)
 	} else cat("x should be an object of class \"densityMap\"\n")
