@@ -40,7 +40,7 @@ plotSimmap<-function(tree,colors=NULL,fsize=1.0,ftype="reg",lwd=2,
 					fg<-par()$fg
 					par(fg="transparent")
 					black<-colors
-					black[]<-"black"
+					black[]<-fg
 					updownPhylogram(tree,colors=black,fsize,ftype,lwd=lwd+2,pts,
 						node.numbers,mar,add,offset,direction,setEnv,xlim,ylim,nodes,
 						tips,split.vertical,lend,asp,plot)
@@ -54,7 +54,7 @@ plotSimmap<-function(tree,colors=NULL,fsize=1.0,ftype="reg",lwd=2,
 					fg<-par()$fg
 					par(fg="transparent")
 					black<-colors
-					black[]<-"black"
+					black[]<-fg
 					plotPhylogram(tree,colors=black,fsize,ftype,lwd=lwd+2,pts,
 						node.numbers,mar,add,offset,direction,setEnv,xlim,ylim,nodes,
 						tips,split.vertical,lend,asp,plot)
@@ -69,7 +69,7 @@ plotSimmap<-function(tree,colors=NULL,fsize=1.0,ftype="reg",lwd=2,
 				fg<-par()$fg
 				par(fg="transparent")
 				black<-colors
-				black[]<-"black"
+				black[]<-fg
 				plotFan(tree,colors=black,fsize,ftype,lwd=lwd+2,mar,add,part,setEnv,
 					xlim,ylim,tips,maxY,lend,plot,offset)
 				par(fg=fg)
@@ -81,7 +81,7 @@ plotSimmap<-function(tree,colors=NULL,fsize=1.0,ftype="reg",lwd=2,
 				fg<-par()$fg
 				par(fg="transparent")
 				black<-colors
-				black[]<-"black"
+				black[]<-fg
 				plotCladogram(tree,colors=black,fsize,ftype,lwd=lwd+2,mar,add,offset,
 					direction,xlim,ylim,nodes,tips,lend,asp,plot)
 				par(fg=fg)
@@ -359,8 +359,9 @@ plotPhylogram<-function(tree,colors,fsize,ftype,lwd,pts,node.numbers,mar,
 
 # function to plot simmap tree in type "fan"
 # written by Liam J. Revell 2013-2017
-plotFan<-function(tree,colors,fsize,ftype,lwd,mar,add,part,setEnv,xlim,ylim,tips,maxY,lend,plot,offset=0){
+plotFan<-function(tree,colors,fsize,ftype,lwd,mar,add,part,setEnv,xlim,ylim,tips,maxY,lend,plot,offset){
 	if(!plot) cat("plot=FALSE option is not permitted for type=\"fan\". Tree will be plotted.\n")
+	if(is.null(offset)) offset<-1
 	# reorder
 	cw<-reorder(tree)
 	pw<-reorder(tree,"pruningwise")
