@@ -1,5 +1,5 @@
 ## some utility functions
-## written by Liam J. Revell 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020
+## written by Liam J. Revell 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021
 
 ## di2multi & multi2di for "contMap" & "densityMap" object classes
 
@@ -444,7 +444,7 @@ getnode<-function(...){
 }
 
 ## function mostly to interactively label nodes by clicking
-## written by Liam J. Revell 2017
+## written by Liam J. Revell 2017, 2020
 labelnodes<-function(text,node=NULL,interactive=TRUE,
 	shape=c("circle","ellipse","rect"),...){
 	shape<-shape[1]
@@ -454,6 +454,8 @@ labelnodes<-function(text,node=NULL,interactive=TRUE,
 	else rect.exp<-1.6
 	if(hasArg(cex)) cex<-list(...)$cex
 	else cex<-1
+	if(hasArg(bg)) bg<-list(...)$bg
+	else bg<-"white"
 	obj<-get("last_plot.phylo",envir=.PlotPhyloEnv)
 	h<-cex*strheight("A")
 	w<-cex*strwidth(text)
@@ -474,15 +476,15 @@ labelnodes<-function(text,node=NULL,interactive=TRUE,
 			node[i]<-ii
 		} else ii<-node[i]
 		if(shape=="circle")
-			draw.circle(obj$xx[ii],obj$yy[ii],rad,col="white")
+			draw.circle(obj$xx[ii],obj$yy[ii],rad,col=bg)
 		else if(shape=="ellipse")
 			draw.ellipse(obj$xx[ii],obj$yy[ii],0.8*w[i],h,
-				col="white")
+				col=bg)
 		else if(shape=="rect")
 			rect(xleft=obj$xx[ii]-0.5*rect.exp*w[i],
 				ybottom=obj$yy[ii]-0.5*rect.exp*h,
 				xright=obj$xx[ii]+0.5*rect.exp*w[i],
-				ytop=obj$yy[ii]+0.5*rect.exp*h,col="white",
+				ytop=obj$yy[ii]+0.5*rect.exp*h,col=bg,
 				ljoin=1)
 		text(obj$xx[ii],obj$yy[ii],label=text[i],cex=cex)
 	}
@@ -1119,12 +1121,12 @@ ladderize.simmap<-function(tree,right=TRUE){
 repPhylo<-function(tree,times) rep(tree,times)
 
 ## S3 method rep for objects of class "phylo" and "multiPhylo"
-## written by Liam J. Revell 2014
+## written by Liam J. Revell 2014, 2021
 
 rep.phylo<-function(x,...){
 	if(hasArg(times)) times<-list(...)$times
 	else times<-(...)[[1]]
-	for(i in 1:times) obj<-if(i==1) x else if(i==2) c(obj,x) else c(obj,list(x))
+	for(i in 1:times) obj<-if(i==1) x else if(i==2) c(obj,x) else c(unclass(obj),list(x))
 	class(obj)<-"multiPhylo"
 	obj
 }
@@ -2128,8 +2130,8 @@ matchType<-function(type,types){
 	return(type)
 }
 	
-# function 'untangles' (or attempts to untangle) a tree with crossing branches
-# written by Liam J. Revell 2013, 2015
+## function 'untangles' (or attempts to untangle) a tree with crossing branches
+## written by Liam J. Revell 2013, 2015, 2020, 2021
 untangle<-function(tree,method=c("reorder","read.tree")){
 	if(inherits(tree,"multiPhylo")){
 		tree<-lapply(tree,untangle,method=method)
@@ -2140,8 +2142,12 @@ untangle<-function(tree,method=c("reorder","read.tree")){
 		method<-method[1]
 		if(method=="reorder") tree<-reorder(reorder(tree,"pruningwise"))
 		else if(method=="read.tree"){
-			if(inherits(tree,"simmap")) tree<-read.simmap(text=write.simmap(tree))
+			tip.label<-tree$tip.label
+			tree$tip.label<-1:Ntip(tree)
+			if(inherits(tree,"simmap")) 
+				tree<-read.simmap(text=capture.output(write.simmap(tree,file=stdout())))
 			else tree<-if(Ntip(tree)>1) read.tree(text=write.tree(tree)) else read.newick(text=write.tree(tree))
+			tree$tip.label<-tip.label[as.numeric(tree$tip.label)]
 		}
 		ii<-!names(obj)%in%names(attributes(tree))
 		attributes(tree)<-c(attributes(tree),obj[ii])
